@@ -30,7 +30,8 @@ private:
 };
 #define USRDBG(nix, msg) LOG(msg)
 #else
-#define USRDBG(nix, msg) { if(acfg::debug & LOG_MORE) {aclog::err( tSS()<<msg); } }
+// print some extra things when user wants debug with non-debug build
+#define USRDBG(nix, msg) { if(acfg::debug & LOG_DEBUG) {aclog::err( tSS()<<msg); } }
 #endif
 
 
