@@ -7,8 +7,8 @@
 #include "acbuf.h"
 #include <sys/types.h>
 
-class fileitem;
-typedef SHARED_PTR<fileitem> tFileItemPtr;
+class fileitem_base;
+typedef SHARED_PTR<fileitem_base> tFileItemPtr;
 
 class con;
 
@@ -54,6 +54,7 @@ class job {
       bool m_bChunkMode;
       bool m_bClientWants2Close;
       bool m_bIsHttp11;
+      bool m_bNoDownloadStarted;
       
       eJobState m_state, m_backstate;
       
@@ -66,7 +67,7 @@ class job {
       header *m_pReqHead; // copy of users requests header
 
       tFileItemPtr m_pItem;
-      off_t m_nSendPos, m_nRangeLast;
+      off_t m_nSendPos, m_nCurrentRangeLast;
       off_t m_nAllDataCount;
       
       unsigned long m_nChunkRemainingBytes;
@@ -80,6 +81,10 @@ class job {
       void SetErrorResponse(const char * errorLine);
       void HandleLocalDownload(const mstring &visPath,
     			const mstring &fsBase, const mstring &fsSubpath);
+
+      bool ParseRange();
+
+      off_t m_nRangeFrom, m_nRangeTo;
 };
 
 #endif
