@@ -1,6 +1,4 @@
 
-
-//#define LOCAL_DEBUG
 #include "debug.h"
 
 #include "acfg.h"
@@ -40,11 +38,27 @@ namespace acfg {
 // internal stuff:
 string sPopularPath("/debian/");
 
-string tmpDontcache, tmpDontcacherq, tmpDontcachetgt, tmpConprotoparm;
+string tmpDontcache, tmpDontcacherq, tmpDontcacheResolved;
 
 tStrMap localdirs;
 NoCaseStringMap mimemap;
 
+MYSTD::bitset<65536> *pUserPorts = NULL;
+
+typedef struct
+{
+	const char *name; mstring *ptr;
+	const char *warn;
+}
+MapNameToString;
+
+typedef struct
+{
+	const char *name; int *ptr;
+	const char *warn; int base;
+}
+MapNameToInt;
+
 #ifndef MINIBUILD
 
 MapNameToString n2sTbl[] = {
@@ -54,7 +68,6 @@ MapNameToString n2sTbl[] = {
 		,{ "SupportDir", 	&suppdir, 0}
 		,{ "SocketPath", 	&fifopath, 0}
 		,{ "PidFile", 	&pidfile, 0}
-		//,{ "Proxy",		&proxy, 0}
 		,{ "ReportPage",&reportpage, 0}
 		,{ "VfilePattern", &vfilepat, 0}
 		,{ "PfilePattern", &pfilepat, 0}
@@ -63,11 +76,10 @@ MapNameToString n2sTbl[] = {
 		,{ "BindAddress", &bindaddr, 0}
 		,{ "UserAgent", &agentname, 0}
 		,{ "DontCache",	&tmpDontcache, 0}
-		,{ "DontCacheRequested",	&tmpDontcachetgt, 0}
-		,{ "DontCacheResolved",	&tmpDontcacherq, 0}
+		,{ "DontCacheRequested",	&tmpDontcacherq, 0}
+		,{ "DontCacheResolved",	&tmpDontcacheResolved, 0}
 		,{ "PrecacheFor", &mirrorsrcs, 0}
 		,{ "RequestAppendix", &requestapx, 0}
-		,{ "ConnectProto", &tmpConprotoparm, 0}
 };
 
 MapNameToInt n2iTbl[] = {
@@ -119,7 +131,7 @@ tMapUrl2StringPtr mapUrl2pVname;
 typedef map<const string, tRepoData> tRepMap;
 tRepMap repoparms;
 
-string * _GetStringPtr(const string &key) {
+string * GetStringPtr(const string &key) {
 	for(unsigned int i=0; i<_countof(n2sTbl); i++)
 	{
 		if(0==strcasecmp(key.c_str(), n2sTbl[i].name))
@@ -133,7 +145,7 @@ string * _GetStringPtr(const string &key) {
 	return NULL;
 }
 
-int * _GetIntPtr(const string &key, int &base) {
+int * GetIntPtr(const string &key, int &base) {
 	for(unsigned int i=0; i<_countof(n2iTbl); i++)
 	{
 		if(0==strcasecmp(key.c_str(), n2iTbl[i].name))
@@ -268,7 +280,7 @@ inline void AddRemapFlag(const string & token, const string &repname)
 	{
 		//if(!startsWithSz(value, "/"))
 		//	value.insert(0, "/");
-		if (acfg::debug>1)
+		if (acfg::debug&LOG_FLUSH)
 			cerr << "Fatal keyfile for " <<repname<<": "<<value <<endl;
 
 		where.m_keyfiles.push_back(value);
@@ -317,7 +329,7 @@ tStrDeq ExpandFileTokens(cmstring &token)
 
 			// hits in confdir will overwrite those from suppdir
 			for (; !srcs.empty(); srcs.pop_back())
-				bname2path[::basename(srcs.back().c_str())] = srcs.back();
+				bname2path[::GetBaseName(srcs.back())] = srcs.back();
 		}
 		if (bname2path.empty())
 		{
@@ -546,9 +558,9 @@ bool SetOption(const string &sLine, bool bQuiet)
 	int * pnTarget;
 	int nNumBase(10);
 
-	if ( NULL != (psTarget = _GetStringPtr(key)))
+	if ( NULL != (psTarget = GetStringPtr(key)))
 		*psTarget=value;
-	else if ( NULL != (pnTarget = _GetIntPtr(key, nNumBase)))
+	else if ( NULL != (pnTarget = GetIntPtr(key, nNumBase)))
 	{
 		const char *pStart=value.c_str();
 		if(! *pStart)
@@ -655,6 +667,55 @@ bool SetOption(const string &sLine, bool bQuiet)
 		}
 		_AddHooksFile(vname);
 	}
+	else if(0==strcasecmp(key.c_str(), "AllowUserPorts"))
+	{
+		if(!pUserPorts)
+			pUserPorts=new bitset<TCP_PORT_MAX>;
+		for(tSplitWalk split(&value); split.Next();)
+		{
+			cmstring s(split);
+			const char *start(s.c_str());
+			char *p(0);
+			unsigned long n=strtoul(start, &p, 10);
+			if(n>=TCP_PORT_MAX || !p || '\0' != *p || p == start)
+			{
+				cerr << "Bad port in AllowUserPorts: " << start <<endl;
+				exit(EXIT_FAILURE);
+			}
+			if(n == 0)
+			{
+				pUserPorts->set();
+				break;
+			}
+			pUserPorts->set(n, true);
+		}
+	}
+	else if(0==strcasecmp(key.c_str(), "ConnectProto"))
+	{
+		int *p = conprotos;
+		for (tSplitWalk split(&value); split.Next(); ++p)
+		{
+			cmstring val(split);
+			if (val.empty())
+				break;
+
+			if (p >= conprotos + _countof(conprotos))
+			{
+				cerr << "Too many protocols specified: " << val << endl;
+				exit(EXIT_FAILURE);
+			}
+
+			if (val == "v6")
+				*p = PF_INET6;
+			else if (val == "v4")
+				*p = PF_INET;
+			else
+			{
+				cerr << "IP protocol not supported: " << val << endl;
+				exit(EXIT_FAILURE);
+			}
+		}
+	}
 	else
 	{
 		if(!bQuiet)
@@ -717,12 +778,12 @@ void ReadBackendsFile(const string & sFile, const string &sRepName)
 	tHttpUrl entry;
 
 	tCfgIter itor(sFile);
-	if(debug>4)
+	if(debug&6)
 		cout << "Reading backend file: " << sFile <<endl;
 
 	if(!itor)
 	{
-		if(debug>4)
+		if(debug&6)
 			cout << "No backend data found, file ignored."<<endl;
 		goto try_read_default;
 	}
@@ -999,6 +1060,10 @@ void PostProcConfig()
    if(!acfg::agentname.empty())
 	   acfg::agentheader=string("User-Agent: ")+acfg::agentname + "\r\n";
    
+   trimString(acfg::requestapx);
+   if(!acfg::requestapx.empty())
+	   acfg::requestapx = unEscape(acfg::requestapx);
+
    if(!adminauth.empty())
 	   adminauth=string("Basic ")+EncodeBase64Auth(adminauth);
    
@@ -1024,36 +1089,16 @@ void PostProcConfig()
 	numcores = (int) sysconf(_SC_NPROC_ONLN);
 #endif
 
-   if(!rechecks::CompileUncExpressions(tmpDontcachetgt.empty() ? tmpDontcache : tmpDontcachetgt,
-		   tmpDontcacherq.empty() ? tmpDontcache : tmpDontcacherq))
+   if(!rechecks::CompileUncExpressions(
+		   tmpDontcacherq.empty() ? tmpDontcache : tmpDontcacherq,
+		   tmpDontcacheResolved.empty() ? tmpDontcache : tmpDontcacheResolved))
    {
 	   cerr << "An error occurred while compiling regular expression for non-cached paths!" <<endl;
 	   exit(EXIT_FAILURE);
    }
-
-   int *p=conprotos;
-   for(tSplitWalk split(&tmpConprotoparm); split.Next(); ++p)
-   {
-	   cmstring val(split);
-	   if(val.empty())
-		   break;
-
-	   if(p>=conprotos+_countof(conprotos))
-	   {
-		   cerr << "Too many protocols specified: " << val <<endl;
-		   exit(EXIT_FAILURE);
-	   }
-
-	   if(val == "v6")
-		   *p=PF_INET6;
-	   else if(val == "v4")
-		   *p=PF_INET;
-	   else
-	   {
-		   cerr << "IP protocol not supported: " << val <<endl;
-		   exit(EXIT_FAILURE);
-	   }
-   }
+   tmpDontcache.clear();
+   tmpDontcacheResolved.clear();
+   tmpDontcacherq.clear();
 
    if(usewrap == RESERVED_DEFVAL)
    {
@@ -1102,19 +1147,6 @@ void PostProcConfig()
 	   cout << "\n\nAdditional debugging information not compiled in.\n\n";
 #endif
    
-   
-   /*
-   // help STL saving some memory
-   for(tUrl2RepIter it=mapUrl2pVname.begin(); it!=mapUrl2pVname.end(); it++)
-   {
-	   tUrl2RepIter suc=it;
-	   suc++;
-	   if(suc==mapUrl2pVname.end()) break;
-	   if(suc->first.sPath==it->first.sPath)
-		   const_cast<string&>(suc->first.sPath)=it->first.sPath;
-   }
-   */
-
 #if 0 //def DEBUG
 #warning adding hook control pins
    for(tMapString2Hostivec::iterator it = repoparms.begin();
@@ -1163,7 +1195,7 @@ time_t ExecutePostponed()
 		{
 			if (hooks.downTimeNext <= now) // time to execute
 			{
-				if(acfg::debug>1)
+				if(acfg::debug&LOG_MORE)
 					aclog::misc(hooks.cmdRel, 'X');
 				if(acfg::debug & LOG_FLUSH)
 					aclog::flush();
@@ -1264,10 +1296,10 @@ inline bool CompileUncachedRex(const string & token, bool bIsTgtPattern, bool bR
 }
 
 
-bool CompileUncExpressions(const string & req, const string & tgt)
+bool CompileUncExpressions(const string & req, const string & resolved)
 {
 	for(int i=0; i<2; ++i) // req, tgt, stop
-		for(tSplitWalk split(i? &req : &tgt); split.Next(); )
+		for(tSplitWalk split(i? &req : &resolved); split.Next(); )
 			if (!CompileUncachedRex(split, i, false))
 				return false;
 	return true;
