@@ -139,7 +139,7 @@ void GetStats(deque<tRowData> & out)
 		out.push_back(d);
 	}
 	
-#warning stats cache disabled, restore it later?
+//#warning stats cache disabled, restore it later?
 #if 0
 	struct stat statbuf;
 	
@@ -327,13 +327,15 @@ errnoFmter::errnoFmter(const char *prefix)
 	if(prefix)
 		assign(prefix);
 
-	int err=errno;
-
 #ifdef _GNU_SOURCE
 //#warning COMPILER BUG DETECTED -- _GNU_SOURCE was preset in C++ mode
-	append(strerror_r(err, buf, sizeof(buf)-1));
+	append(strerror_r(errno, buf, sizeof(buf)-1));
 #else
-	append(strerror_r(errno, buf, sizeof(buf)-1) ? "UNKNOWN ERROR" : buf);
+	int err=errno;
+	if(strerror_r(err, buf, sizeof(buf)-1))
+		append(tSS() << "UNKNOWN ERROR: " << err);
+	else
+		append(buf);
 #endif
 }
 
@@ -342,7 +344,7 @@ errnoFmter::errnoFmter(const char *prefix)
 #ifdef DEBUG
 
 static lockable mx_dbgStackMark;
-MYSTD::map<pthread_t, int> stackDepths;
+MYMAP<pthread_t, int> stackDepths;
 t_logger::t_logger(const char *szFuncName,  const void * ptr)
 {
 	m_id = pthread_self();
