@@ -6,7 +6,7 @@
 #include "config.h"
 #include "meta.h"
 #include "acfg.h"
-#include "expiration.h"
+#include "fileio.h"
 #include "conserver.h"
 
 #include <iostream>
@@ -24,6 +24,8 @@ void term_handler(int signum);
 void log_handler(int signum);
 void check_algos();
 
+void DispatchAndRunMaintTask(cmstring &cmd, int fd, const char *auth);
+
 #ifndef HAVE_DAEMON // provide a poor but sufficient replacement
 int daemon(int, int)
 {
@@ -93,7 +95,7 @@ int main(int argc, char **argv)
 	const char *toBase64=getenv("TOBASE64");
 	if(toBase64)
 	{
-		std::cout << acfg::EncodeBase64Auth(toBase64);
+		MYSTD::cout << acfg::EncodeBase64Auth(toBase64);
 		return 0;
 	}
 
@@ -173,9 +175,10 @@ int main(int argc, char **argv)
 
 	conserver::Setup();
 	
-	if (bForceCleanup) {
-		expiration ex(fileno(stdout));
-		ex.Run("");
+	if (bForceCleanup)
+	{
+		DispatchAndRunMaintTask(acfg::reportpage + "?abortOnErrors=aOe&doExpire=Start",
+				fileno(stdout), acfg::adminauth.c_str());
 		exit(0);
 	}
 
