@@ -104,7 +104,7 @@ public:
 		int ofd = m_spOutCon->GetFD();
 		acbuf &serverBufOut = clientBufIn, &serverBufIn = clientBufOut;
 
-		int maxfd=1+std::max(fdClient, ofd);
+		int maxfd=1+MYSTD::max(fdClient, ofd);
 
 		while (true)
 		{
