@@ -19,6 +19,10 @@
 #include <map>
 #include <iostream>
 
+#ifdef HAVE_LIBWRAP
+#include <tcpd.h>
+#endif
+
 #include "debug.h"
 
 using namespace MYSTD;
@@ -28,6 +32,7 @@ using namespace MYSTD;
 #define AF_INET6        23              /* IP version 6 */
 #endif
 
+
 namespace conserver
 {
 
@@ -210,7 +215,7 @@ void CreateUnixSocket() {
 	if (g_sockunix<0)
 		goto unx_err;
 	
-	if (bind(g_sockunix, (struct sockaddr *)&addr_unx, size) < 0)
+	if (::bind(g_sockunix, (struct sockaddr *)&addr_unx, size) < 0)
 		goto unx_err;
 	
 	if (0==listen(g_sockunix, SO_MAXCONN))
@@ -279,7 +284,7 @@ void Setup()
 				setsockopt(sockip, SOL_SOCKET, SO_REUSEADDR, &yes, sizeof(yes));
 				
 				
-		    	if (bind(sockip, p->ai_addr, p->ai_addrlen))
+		    	if (::bind(sockip, p->ai_addr, p->ai_addrlen))
 		    		goto error_bind;
 		    	if (listen(sockip, SO_MAXCONN))
 		    		goto error_listen;
@@ -398,6 +403,7 @@ int Run()
 					set_nb(fd);
 					char hbuf[NI_MAXHOST];
 					USRDBG(1, "Detected incoming connection from the TCP socket");
+
 					if (getnameinfo((struct sockaddr*) &addr, addrlen, hbuf, sizeof(hbuf),
 									NULL, 0, NI_NUMERICHOST))
 					{
@@ -406,6 +412,23 @@ int Run()
 						sleep(1);
 						continue;
 					}
+
+#ifdef HAVE_LIBWRAP
+					if (acfg::usewrap)
+					{
+						// libwrap code is evil non-reentrant stuff, call it from here only
+						request_info req;
+						request_init(&req, RQ_DAEMON, "apt-cacher-ng", RQ_FILE, fd, 0);
+						fromhost(&req);
+						if (!hosts_access(&req))
+						{
+							aclog::err("ERROR: access not permitted by hosts files", hbuf);
+							forceShutdownClose(fd);
+							continue;
+						}
+					}
+#endif
+
 					SetupConAndGo(fd, hbuf);
 				}
 				else if(errno == EMFILE || errno == ENOMEM || ENOBUFS == errno)
