@@ -327,8 +327,12 @@ struct tDlJob
 			}
 			if (m_pStorage->m_bHeadOnly)
 				m_DlState = STATE_FINISHJOB;
-			else if (NULL != (p = h.h[header::TRANSFER_ENCODING]) && 0 == strcasecmp(p, "chunked"))
+			else if (h.h[header::TRANSFER_ENCODING] &&
+					0 == strcasecmp(h.h[header::TRANSFER_ENCODING], "chunked"))
+			{
 				m_DlState = STATE_GETCHUNKHEAD;
+				h.del(header::TRANSFER_ENCODING); // don't care anymore
+			}
 			else
 			{
 				dbgline;
