@@ -885,7 +885,6 @@ job::eJobResult job::SendData(int confd, int nAllJobCount)
 					if(n<0)
 						THROW_ERROR("400 Client error");
 					
-					
 					return R_AGAIN;
 				}
 				case(STATE_SEND_CHUNK_HEADER):
@@ -986,39 +985,14 @@ inline const char * job::BuildAndEnqueHeader(const FiStatus &fistate,
 	if(respHead.type != header::ANSWER)
 		return "500 Rotten Data";
 
-#if 0 // defined DEBUG
-	respHead.h[header::CONTENT_LENGTH]=0;
-	respHead.set(header::TRANSFER_ENCODING, "chunked");
-#endif
-
 	// make sure that header has consistent state and there is data to send which is expected by the client
-	bool bHasSendableData = false;
 	int httpstatus = respHead.getStatus();
 	LOG("State: " << httpstatus);
-	if (!BODYFREECODE(httpstatus)) // never for not-unmodified&co.
-	{
-		bool bChunked = respHead.h[header::TRANSFER_ENCODING] && 0 == strncasecmp( respHead.h[header::TRANSFER_ENCODING], "chunk", 5);
-		if (httpstatus == 200)
-		{
-			if (bChunked)
-			{
-				// chunked data, usually ok...
-				if (respHead.h[header::CONTENT_LENGTH])
-				{
-					aclog::err("internal error: chunked transfer encoding and content length value are both set");
-					respHead.del(header::CONTENT_LENGTH);
-				}
-				bHasSendableData = true;
-			}
-			else
-				bHasSendableData	= respHead.h[header::CONTENT_LENGTH];
-			LOG("has contlen? " << bool(respHead.h[header::CONTENT_LENGTH]));
-		}
-		else if (httpstatus >= 300)
-		{
-			bHasSendableData = atoofft(respHead.h[header::CONTENT_LENGTH], 0) || bChunked;
-		}
-	}
+
+	// nothing to send for special codes (not-unmodified&co.) or zero length bodies
+	bool bHasSendableData = !BODYFREECODE(httpstatus)
+			&& atoofft(respHead.h[header::CONTENT_LENGTH], 0);
+	// if that's a status for object with body but contlen is missing -> use chunked mode later
 
 	tSS &sb=m_sendbuf;
 	sb.clear();
