@@ -40,6 +40,9 @@ tWUIPage::~tWUIPage()
 
 bool tWUIPage::SendRawData(const char *data, size_t len, int flags)
 {
+	if(m_reportFD<3) // nothing raw to send for stdout
+		return true;
+
 	while(len>0)
 	{
 		int r=send(m_reportFD, data, len, flags);
@@ -62,6 +65,12 @@ void tWUIPage::SendChunk(const char *data, size_t len)
 	if(!data || !len || m_reportFD<0)
 		return;
 
+	if(m_reportFD<3)
+	{
+		write(m_reportFD, data, len);
+		return;
+	}
+
 	char buf[23];
 	int l=sprintf(buf, "%x\r\n", (UINT) len);
 	SendRawData(buf, l, MSG_MORE|MSG_NOSIGNAL);
@@ -150,8 +159,8 @@ string & tWUIPage::GetHostname()
 	return m_sHostname;
 }
 
-void DispatchAndRunMaintTask(MYSTD::string &cmd, int conFD, const char * szAuthLine)
-{	
+void DispatchAndRunMaintTask(cmstring &cmd, int conFD, const char * szAuthLine)
+{
 	tWUIPage *pWorker(NULL);
 	if(!szAuthLine)
 		szAuthLine="";
@@ -168,41 +177,49 @@ void DispatchAndRunMaintTask(MYSTD::string &cmd, int conFD, const char * szAuthL
 	
 	MYTRY
 	{
-		//std::cout << "vgl: " << authLine << " und " << acfg::adminauth << "\n";
+		//MYSTD::cout << "vgl: " << authLine << " und " << acfg::adminauth << "\n";
 		// admin actions are passed with GET parameters, appended after ?
 		tStrPos qpos=cmd.find('?');
-		reeval_cmd:
 		if(qpos!=stmiss)
 		{
 			if( ! acfg::adminauth.empty() && acfg::adminauth!=szAuthLine )
 				pWorker = new tAuthRequest(conFD);
-			else if(cmd.find("doExpire=")!=stmiss || 
-					cmd.find("justShow=")!=stmiss ||
-					cmd.find("justRemove=")!=stmiss)
-				pWorker = new expiration(conFD);
+			else if(StrHas(cmd, "doExpire="))
+				pWorker = new expiration(conFD, expiration::expire);
+			else if(StrHas(cmd, "justShow="))
+				pWorker = new expiration(conFD, expiration::list);
+			else if(StrHas(cmd, "justRemove="))
+				pWorker = new expiration(conFD, expiration::purge);
+			else if(StrHas(cmd, "justShowDamaged="))
+				pWorker = new expiration(conFD, expiration::listDamaged);
+			else if(StrHas(cmd, "justRemoveDamaged="))
+				pWorker = new expiration(conFD, expiration::purgeDamaged);
 			else if(cmd.find("doImport=")!=stmiss)
 				pWorker=new pkgimport(conFD);
 			else if(cmd.find("doMirror=")!=stmiss)
+			{
 				if(acfg::adminauth.empty())
 					pWorker=new authbounce(conFD);
 				else
 					pWorker=new pkgmirror(conFD);
+			}
 			else if(cmd.find("doDelete=")!=stmiss ||cmd.find("doDeleteYes=")!=stmiss)
+			{
 				if(acfg::adminauth.empty())
 					pWorker=new authbounce(conFD);
 				else
 					pWorker=new tDeleter(conFD);
+			}
 			else if(cmd.find("doCount=")!=stmiss)
 				pWorker = new tStaticFileSend(conFD, "report.html", "text/html", "200");
 			else // ok... just show the default page
-			{
-				cmd=cmd.substr(0,qpos);
-				qpos=stmiss;
-				goto reeval_cmd;
-			}
+				goto l_show_cnc;
 		}
 		else if (cmd==acfg::reportpage)
+		{
+			l_show_cnc:
 			pWorker = new tStaticFileSend(conFD, "report.html", "text/html", "200");
+		}
 		else if (cmd == "/style.css")
 			pWorker = new tStaticFileSend(conFD, "style.css", "text/css", "200");
 		else
